'''
Manage HDInsight cluster's Autoscale configuration.
'''
from ... pyaz_utils import _call_az
from . import condition


def create(cluster_name, resource_group, type, days=None, max_workernode_count=None, min_workernode_count=None, no_wait=None, time=None, timezone=None, workernode_count=None, yes=None):
    '''
    Enable Autoscale for a running cluster.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - type -- The autoscale type.

    Optional Parameters:
    - days -- A space-delimited list of schedule day.
    - max_workernode_count -- The max workernode count for Load-based atuoscale.
    - min_workernode_count -- The minimal workernode count for Load-based atuoscale.
    - no_wait -- Do not wait for the long-running operation to finish.
    - time -- The 24-hour time in the form xx:xx in days.
    - timezone -- The timezone for schedule autoscale type. Values from `az hdinsight autoscale list-timezones`
    - workernode_count -- The schedule workernode count.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az hdinsight autoscale create", locals())


def update(cluster_name, resource_group, max_workernode_count=None, min_workernode_count=None, no_wait=None, timezone=None):
    '''
    Update the Autoscale configuration.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - max_workernode_count -- The max workernode count for Load-based atuoscale.
    - min_workernode_count -- The minimal workernode count for Load-based atuoscale.
    - no_wait -- Do not wait for the long-running operation to finish.
    - timezone -- The timezone for schedule autoscale type. Values from `az hdinsight autoscale list-timezones`
    '''
    return _call_az("az hdinsight autoscale update", locals())


def show(cluster_name, resource_group):
    '''
    Get the Autoscale configuration of a specified cluster.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az hdinsight autoscale show", locals())


def delete(cluster_name, resource_group, no_wait=None, yes=None):
    '''
    Disable Autoscale for a running cluster.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az hdinsight autoscale delete", locals())


def list_timezones():
    '''
    List the available timezone name when enabling Schedule-based Autoscale.
    '''
    return _call_az("az hdinsight autoscale list-timezones", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until an operation is complete.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az hdinsight autoscale wait", locals())




'''
Manage delivery rule actions for a rule.
'''
from .... pyaz_utils import _call_az

def add(action_name, profile_name, resource_group, rule_name, rule_set_name, cache_behavior=None, cache_duration=None, custom_fragment=None, custom_hostname=None, custom_path=None, custom_querystring=None, destination=None, header_action=None, header_name=None, header_value=None, preserve_unmatched_path=None, query_parameters=None, query_string_behavior=None, redirect_protocol=None, redirect_type=None, source_pattern=None):
    '''
    Add an action to a delivery rule.

    Required Parameters:
    - action_name -- Name of the action.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- Name of the rule.
    - rule_set_name -- Name of the rule set.

    Optional Parameters:
    - cache_behavior -- Caching behavior for the requests.
    - cache_duration -- The duration for which the content needs to be cached.                Allowed format is [d.]hh:mm:ss.
    - custom_fragment -- Fragment to add to the redirect URL.
    - custom_hostname -- Host to redirect.                Leave empty to use the incoming host as the destination host.
    - custom_path -- The full path to redirect. Path cannot be empty and must start with /.                Leave empty to use the incoming path as destination path.
    - custom_querystring -- The set of query strings to be placed in the redirect URL.                leave empty to preserve the incoming query string.
    - destination -- The destination path to be used in the rewrite.
    - header_action -- Header action for the requests.
    - header_name -- Name of the header to modify.
    - header_value -- Value of the header.
    - preserve_unmatched_path -- If True, the remaining path after the source                pattern will be appended to the new destination path.
    - query_parameters -- Query parameters to include or exclude (comma separated).
    - query_string_behavior -- Query string behavior for the requests.
    - redirect_protocol -- Protocol to use for the redirect.
    - redirect_type -- The redirect type the rule will use when redirecting traffic.
    - source_pattern -- A request URI pattern that identifies the type of requests that may be rewritten.
    '''
    return _call_az("az afd rule action add", locals())


def remove(index, profile_name, resource_group, rule_name, rule_set_name):
    '''
    Remove an action from a delivery rule.

    Required Parameters:
    - index -- The index of the condition/action
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- Name of the rule.
    - rule_set_name -- Name of the rule set.
    '''
    return _call_az("az afd rule action remove", locals())


def list(profile_name, resource_group, rule_name, rule_set_name):
    '''
    show actions asscociated with the rule.

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- Name of the rule.
    - rule_set_name -- Name of the rule set.
    '''
    return _call_az("az afd rule action list", locals())




'''
Manage the managed data disks attached to a VM.
'''
from ... pyaz_utils import _call_az

def attach(name, resource_group, vm_name, caching=None, enable_write_accelerator=None, lun=None, new=None, size_gb=None, sku=None):
    '''
    Attach a managed persistent disk to a VM. Please note that --ids only supports one disk.

    Required Parameters:
    - name -- The name or ID of the managed disk
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`

    Optional Parameters:
    - caching -- Disk caching policy
    - enable_write_accelerator -- enable write accelerator
    - lun -- 0-based logical unit number (LUN). Max value depends on the Virtual Machine size.
    - new -- create a new disk
    - size_gb -- size in GB. Max size: 4095 GB (certain preview disks can be larger).
    - sku -- Underlying storage SKU
    '''
    return _call_az("az vm disk attach", locals())


def detach(name, resource_group, vm_name):
    '''
    Detach a managed disk from a VM.

    Required Parameters:
    - name -- The data disk name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    '''
    return _call_az("az vm disk detach", locals())




'''
Manage Synapse Spark statements.
'''
from .... pyaz_utils import _call_az

def invoke(code, language, session_id, spark_pool_name, workspace_name):
    '''
    Invoke a Spark statement.

    Required Parameters:
    - code -- The code of Spark statement. This is either the code contents or use `@<file path>` to load the content from a file
    - language -- The language of Spark statement.
    - session_id -- The id of Spark session.
    - spark_pool_name -- The name of the Spark pool.
    - workspace_name -- The name of the workspace.
    '''
    return _call_az("az synapse spark statement invoke", locals())


def list(session_id, spark_pool_name, workspace_name):
    '''
    List all Spark statements

    Required Parameters:
    - session_id -- The id of Spark session.
    - spark_pool_name -- The name of the Spark pool.
    - workspace_name -- The name of the workspace.
    '''
    return _call_az("az synapse spark statement list", locals())


def show(livy_id, session_id, spark_pool_name, workspace_name):
    '''
    Get a Spark statement.

    Required Parameters:
    - livy_id -- The id of the statement.
    - session_id -- The id of Spark session.
    - spark_pool_name -- The name of the Spark pool.
    - workspace_name -- The name of the workspace.
    '''
    return _call_az("az synapse spark statement show", locals())


def cancel(livy_id, session_id, spark_pool_name, workspace_name, yes=None):
    '''
    Cancel a Spark statement.

    Required Parameters:
    - livy_id -- The id of the statement.
    - session_id -- The id of Spark session.
    - spark_pool_name -- The name of the Spark pool.
    - workspace_name -- The name of the workspace.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse spark statement cancel", locals())




from .... pyaz_utils import _call_az
from . import keys


def create(hybrid_connection_name, name, namespace_name, resource_group, rights=None):
    '''
    Create Authorization Rule for given Relay Service Hybrid Connection

    Required Parameters:
    - hybrid_connection_name -- name of Hybrid Connection
    - name -- name of Hybrid Connection Authorization Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - rights -- Space-separated list of Authorization rule rights
    '''
    return _call_az("az relay hyco authorization-rule create", locals())


def show(hybrid_connection_name, name, namespace_name, resource_group):
    '''
    Shows the details of Authorization Rule for given Relay Service Hybrid Connection

    Required Parameters:
    - hybrid_connection_name -- name of Hybrid Connection
    - name -- name of Hybrid Connection Authorization Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az relay hyco authorization-rule show", locals())


def list(hybrid_connection_name, namespace_name, resource_group):
    '''
    shows list of Authorization Rule by Relay Service Hybrid Connection

    Required Parameters:
    - hybrid_connection_name -- name of Hybrid Connection
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az relay hyco authorization-rule list", locals())


def delete(hybrid_connection_name, name, namespace_name, resource_group):
    '''
    Deletes the Authorization Rule of the given Relay Service Hybrid Connection.

    Required Parameters:
    - hybrid_connection_name -- name of Hybrid Connection
    - name -- name of Hybrid Connection Authorization Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az relay hyco authorization-rule delete", locals())


def update(hybrid_connection_name, name, namespace_name, resource_group, rights, add=None, force_string=None, remove=None, set=None):
    '''
    Create Authorization Rule for given Relay Service Hybrid Connection

    Required Parameters:
    - hybrid_connection_name -- name of Hybrid Connection
    - name -- name of Hybrid Connection Authorization Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rights -- Space-separated list of Authorization rule rights

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az relay hyco authorization-rule update", locals())




'''
Manage Synapse's pipelines.
'''
from ... pyaz_utils import _call_az

def create(file, name, workspace_name, no_wait=None):
    '''
    Create a pipeline.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The pipeline name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse pipeline create", locals())


def set(file, name, workspace_name, no_wait=None):
    '''
    Update an exist pipeline.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The pipeline name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse pipeline set", locals())


def update(file, name, workspace_name, no_wait=None):
    '''
    Update an exist pipeline.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The pipeline name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse pipeline update", locals())


def list(workspace_name):
    '''
    List pipelines.

    Required Parameters:
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse pipeline list", locals())


def show(name, workspace_name):
    '''
    Get a pipeline.

    Required Parameters:
    - name -- The pipeline name.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse pipeline show", locals())


def delete(name, workspace_name, no_wait=None, yes=None):
    '''
    Delete a pipeline.

    Required Parameters:
    - name -- The pipeline name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse pipeline delete", locals())


def create_run(name, workspace_name, is_recovery=None, parameters=None, reference_pipeline_run_id=None, start_activity_name=None):
    '''
    Creates a run of a pipeline.

    Required Parameters:
    - name -- The pipeline name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - is_recovery -- Recovery mode flag. If recovery mode is set to true, the specified referenced pipeline run and the new run will be grouped under the same groupId.
    - parameters -- Parameters for pipeline run. Can be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - reference_pipeline_run_id -- The pipeline run ID for rerun. If run ID is specified, the parameters of the specified run will be used to create a new run.
    - start_activity_name -- In recovery mode, the rerun will start from this activity. If not specified, all activities will run.
    '''
    return _call_az("az synapse pipeline create-run", locals())




'''
Manage IoT Central applications.
'''
from .... pyaz_utils import _call_az

def create(name, resource_group, subdomain, display_name=None, location=None, no_wait=None, sku=None, template=None):
    '''
    Create an IoT Central application.

    Required Parameters:
    - name -- Give your IoT Central app a unique name so you can find it later.This will be used as the resource name in the Azure portal and CLI.Avoid special characters `-` instead, use lower case letters (a-z), numbers (0-9), and dashes (-)
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subdomain -- Enter a unique URL. Your app will be accessible via https://<subdomain>.azureiotcentral.com/. Avoid special characters `-` instead, use lower case letters (a-z), numbers (0-9), and dashes (-).

    Optional Parameters:
    - display_name -- Custom display name for the IoT Central app. This will be used in the IoT Central application manager to help you identify your app. Default value is the resource name.
    - location -- Where your app's info and resources are stored. We will default to the location of the target resource group. See documentation for a full list of supported locations.
    - no_wait -- Do not wait for the long-running operation to finish.
    - sku -- Pricing plan for IoT Central application.
    - template -- IoT Central application template name. Default is "Custom application". See documentation for a list of available templates.
    '''
    return _call_az("az iot central app create", locals())


def list(resource_group=None):
    '''
    List IoT Central applications.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot central app list", locals())


def show(name, resource_group=None):
    '''
    Get the details of an IoT Central application.

    Required Parameters:
    - name -- IoT Central application name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot central app show", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update metadata for an IoT Central application.

    Required Parameters:
    - name -- IoT Central application name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az iot central app update", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete an IoT Central application.

    Required Parameters:
    - name -- IoT Central application name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az iot central app delete", locals())




from .... pyaz_utils import _call_az

def create(account_name, body, container_name, database_name, name, resource_group):
    '''
    Create an SQL user defined function under an Azure Cosmos DB SQL container.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - body -- UserDefinedFunction body, you can enter it as a string or as a file, e.g., --body @udfbody-file.json
    - container_name -- Container name.
    - database_name -- Database name.
    - name -- UserDefinedFunction name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb sql user-defined-function create", locals())


def update(account_name, body, container_name, database_name, name, resource_group):
    '''
    

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - body -- UserDefinedFunction body, you can enter it as a string or as a file, e.g., --body @udfbody-file.json
    - container_name -- Container name.
    - database_name -- Database name.
    - name -- UserDefinedFunction name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb sql user-defined-function update", locals())


def list(account_name, container_name, database_name, resource_group):
    '''
    List the SQL user defined functions under an Azure Cosmos DB SQL container.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - container_name -- Container name.
    - database_name -- Database name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb sql user-defined-function list", locals())


def show(account_name, container_name, database_name, name, resource_group):
    '''
    Show the details of a SQL user defined function under an Azure Cosmos DB SQL container.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - container_name -- Container name.
    - database_name -- Database name.
    - name -- UserDefinedFunction name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb sql user-defined-function show", locals())


def delete(account_name, container_name, database_name, name, resource_group, yes=None):
    '''
    Delete the SQL user defined function under an Azure Cosmos DB SQL container.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - container_name -- Container name.
    - database_name -- Database name.
    - name -- UserDefinedFunction name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cosmosdb sql user-defined-function delete", locals())




from ... pyaz_utils import _call_az

def show(location, name, resource_group):
    '''
    

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the Instance Failover Group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql instance-failover-group show", locals())


def create(name, partner_mi, partner_resource_group, resource_group, source_mi, failover_policy=None, grace_period=None):
    '''
    Creates an instance failover group between two connected managed instances.

    Required Parameters:
    - name -- The name of the Instance Failover Group
    - partner_mi -- The name of the partner managed instance of a Instance Failover Group
    - partner_resource_group -- The name of the resource group of the partner managed instance
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source_mi -- Name of the Azure SQL managed instance.

    Optional Parameters:
    - failover_policy -- The failover policy of the Instance Failover Group
    - grace_period -- Interval in hours before automatic failover is initiated if an outage occurs on the primary server. This indicates that Azure SQL Database will not initiate automatic failover before the grace period expires. Please note that failover operation with --allow-data-loss option might cause data loss due to the nature of asynchronous synchronization.
    '''
    return _call_az("az sql instance-failover-group create", locals())


def update(location, name, resource_group, add=None, failover_policy=None, force_string=None, grace_period=None, remove=None, set=None):
    '''
    Updates the instance failover group.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the Instance Failover Group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - failover_policy -- The failover policy of the Instance Failover Group
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - grace_period -- Interval in hours before automatic failover is initiated if an outage occurs on the primary server. This indicates that Azure SQL Database will not initiate automatic failover before the grace period expires. Please note that failover operation with --allow-data-loss option might cause data loss due to the nature of asynchronous synchronization.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az sql instance-failover-group update", locals())


def delete(location, name, resource_group):
    '''
    

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the Instance Failover Group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql instance-failover-group delete", locals())


def set_primary(location, name, resource_group, allow_data_loss=None):
    '''
    Set the primary of the instance failover group by failing over all databases from the current primary managed instance.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the Instance Failover Group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - allow_data_loss -- Complete the failover even if doing so may result in data loss. This will allow the failover to proceed even if a primary database is unavailable.
    '''
    return _call_az("az sql instance-failover-group set-primary", locals())




'''
View your security settings.
'''
from ... pyaz_utils import _call_az

def list():
    '''
    List security settings.
    '''
    return _call_az("az security setting list", locals())


def show(name):
    '''
    Shows a security setting.

    Required Parameters:
    - name -- The name of the setting
    '''
    return _call_az("az security setting show", locals())


def update(enabled, name):
    '''
    Updates a security setting.

    Required Parameters:
    - enabled -- Enable or disable the setting status.
    - name -- The name of the setting
    '''
    return _call_az("az security setting update", locals())




'''
Manage an existing function app's container settings.
'''
from .... pyaz_utils import _call_az

def set(name, resource_group, docker_custom_image_name=None, docker_registry_server_password=None, docker_registry_server_url=None, docker_registry_server_user=None, slot=None):
    '''
    Set an existing function app's container settings.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - docker_custom_image_name -- the container custom image name and optionally the tag name
    - docker_registry_server_password -- the container registry server password
    - docker_registry_server_url -- the container registry server url
    - docker_registry_server_user -- the container registry server username
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp config container set", locals())


def delete(name, resource_group, slot=None):
    '''
    Delete an existing function app's container settings.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp config container delete", locals())


def show(name, resource_group, slot=None):
    '''
    Get details of a function app's container settings.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp config container show", locals())




from ..... pyaz_utils import _call_az

def show(resource_group, zone_name, name=None, record_type=None):
    '''
    Get the details of an SOA record.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.

    Optional Parameters:
    - name -- ==SUPPRESS==
    - record_type -- ==SUPPRESS==
    '''
    return _call_az("az network private-dns record-set soa show", locals())


def update(resource_group, zone_name, email=None, expire_time=None, host=None, minimum_ttl=None, refresh_time=None, retry_time=None, serial_number=None):
    '''
    Update properties of an SOA record.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.

    Optional Parameters:
    - email -- Email address.
    - expire_time -- Expire time (seconds).
    - host -- Host name.
    - minimum_ttl -- Minimum TTL (time-to-live, seconds).
    - refresh_time -- Refresh value (seconds).
    - retry_time -- Retry time (seconds).
    - serial_number -- Serial number.
    '''
    return _call_az("az network private-dns record-set soa update", locals())




from ... pyaz_utils import _call_az
from . import db, deploy, firewall_rule, parameter, replica


def create(address_prefixes=None, admin_password=None, admin_user=None, backup_retention=None, database_name=None, geo_redundant_backup=None, high_availability=None, iops=None, location=None, name=None, private_dns_zone=None, public_access=None, resource_group=None, sku_name=None, standby_zone=None, storage_auto_grow=None, storage_size=None, subnet=None, subnet_prefixes=None, tags=None, tier=None, version=None, vnet=None, yes=None, zone=None):
    '''
    Create a MySQL flexible server.

    Optional Parameters:
    - address_prefixes -- The IP address prefix to use when creating a new virtual network in CIDR format. Default value is 10.0.0.0/16.
    - admin_password -- The password of the administrator. Minimum 8 characters and maximum 128 characters. Password must contain characters from three of the following categories: English uppercase letters, English lowercase letters, numbers, and non-alphanumeric characters.
    - admin_user -- Administrator username for the server. Once set, it cannot be changed. 
    - backup_retention -- The number of days a backup is retained. Range of 1 to 35 days. Default is 7 days.
    - database_name -- The name of the database to be created when provisioning the database server
    - geo_redundant_backup -- Whether or not geo redundant backup is enabled.
    - high_availability -- Enable (ZoneRedundant or SameZone) or disable high availability feature. Default value is Disabled. High availability can only be set during flexible server create time. 
    - iops -- Number of IOPS to be allocated for this server. You will get certain amount of free IOPS based on compute and storage provisioned. The default value for IOPS is free IOPS. To learn more about IOPS based on compute and storage, refer to IOPS in Azure Database for MySQL Flexible Server
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - private_dns_zone -- This parameter only applies for a server with private access. The name or id of new or existing private dns zone. You can use the private dns zone from same resource group, different resource group, or different subscription. If you want to use a zone from different resource group or subscription, please provide resource Id. CLI creates a new private dns zone within the same resource group as virtual network if not provided by users.
    - public_access -- Determines the public access. Enter single or range of IP addresses to be included in the allowed list of IPs. IP address ranges must be dash-separated and not contain any spaces. Specifying 0.0.0.0 allows public access from any resources deployed within Azure to access your server. Setting it to "None" sets the server in public access mode but does not create a firewall rule. 
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku_name -- The name of the compute SKU. Follows the convention Standard_{VM name}. Examples: Standard_D4s_v3
    - standby_zone -- The availability zone information of the standby server when high availability is enabled.
    - storage_auto_grow -- Enable or disable autogrow of the storage. Default value is Enabled.
    - storage_size -- The storage capacity of the server. Minimum is 32 GiB and max is 16 TiB.
    - subnet -- Name or resource ID of a new or existing subnet. If you want to use a subnet from different resource group or subscription, please provide resource ID instead of name. Please note that the subnet will be delegated to flexibleServers. After delegation, this subnet cannot be used for any other type of Azure resources.
    - subnet_prefixes -- The subnet IP address prefix to use when creating a new subnet in CIDR format. Default value is 10.0.0.0/24.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tier -- Compute tier of the server. Accepted values: Burstable, GeneralPurpose, Memory Optimized 
    - version -- Server major version.
    - vnet -- Name or ID of a new or existing virtual network. If you want to use a vnet from different resource group or subscription, please provide a resource ID. The name must be between 2 to 64 characters. The name must begin with a letter or number, end with a letter, number or underscore, and may contain only letters, numbers, underscores, periods, or hyphens.
    - yes -- Do not prompt for confirmation.
    - zone -- Availability zone into which to provision the resource.
    '''
    return _call_az("az mysql flexible-server create", locals())


def restore(name, resource_group, source_server, address_prefixes=None, no_wait=None, private_dns_zone=None, public_access=None, restore_time=None, subnet=None, subnet_prefixes=None, vnet=None, yes=None, zone=None):
    '''
    Restore a flexible server from backup.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source_server -- The name or resource ID of the source server to restore from.

    Optional Parameters:
    - address_prefixes -- The IP address prefix to use when creating a new virtual network in CIDR format. Default value is 10.0.0.0/16.
    - no_wait -- Do not wait for the long-running operation to finish.
    - private_dns_zone -- This parameter only applies for a server with private access. The name or id of new or existing private dns zone. You can use the private dns zone from same resource group, different resource group, or different subscription. If you want to use a zone from different resource group or subscription, please provide resource Id. CLI creates a new private dns zone within the same resource group as virtual network if not provided by users.
    - public_access -- Determines the public access. 
    - restore_time -- The point in time in UTC to restore from (ISO8601 format), e.g., 2017-04-26T02:10:00+00:00The default value is set to current time.
    - subnet -- Name or resource ID of a new or existing subnet. If you want to use a subnet from different resource group or subscription, please provide resource ID instead of name. Please note that the subnet will be delegated to flexibleServers. After delegation, this subnet cannot be used for any other type of Azure resources.
    - subnet_prefixes -- The subnet IP address prefix to use when creating a new subnet in CIDR format. Default value is 10.0.0.0/24.
    - vnet -- Name or ID of a new or existing virtual network. If you want to use a vnet from different resource group or subscription, please provide a resource ID. The name must be between 2 to 64 characters. The name must begin with a letter or number, end with a letter, number or underscore, and may contain only letters, numbers, underscores, periods, or hyphens.
    - yes -- Do not prompt for confirmation.
    - zone -- Availability zone into which to provision the resource.
    '''
    return _call_az("az mysql flexible-server restore", locals())


def geo_restore(location, name, resource_group, source_server, address_prefixes=None, no_wait=None, private_dns_zone=None, public_access=None, subnet=None, subnet_prefixes=None, vnet=None, yes=None, zone=None):
    '''
    Geo-restore a flexible server from backup.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source_server -- The name or resource ID of the source server to restore from.

    Optional Parameters:
    - address_prefixes -- The IP address prefix to use when creating a new virtual network in CIDR format. Default value is 10.0.0.0/16.
    - no_wait -- Do not wait for the long-running operation to finish.
    - private_dns_zone -- This parameter only applies for a server with private access. The name or id of new or existing private dns zone. You can use the private dns zone from same resource group, different resource group, or different subscription. If you want to use a zone from different resource group or subscription, please provide resource Id. CLI creates a new private dns zone within the same resource group as virtual network if not provided by users.
    - public_access -- Determines the public access. 
    - subnet -- Name or resource ID of a new or existing subnet. If you want to use a subnet from different resource group or subscription, please provide resource ID instead of name. Please note that the subnet will be delegated to flexibleServers. After delegation, this subnet cannot be used for any other type of Azure resources.
    - subnet_prefixes -- The subnet IP address prefix to use when creating a new subnet in CIDR format. Default value is 10.0.0.0/24.
    - vnet -- Name or ID of a new or existing virtual network. If you want to use a vnet from different resource group or subscription, please provide a resource ID. The name must be between 2 to 64 characters. The name must begin with a letter or number, end with a letter, number or underscore, and may contain only letters, numbers, underscores, periods, or hyphens.
    - yes -- Do not prompt for confirmation.
    - zone -- Availability zone into which to provision the resource.
    '''
    return _call_az("az mysql flexible-server geo-restore", locals())


def start(name, resource_group):
    '''
    Start a flexible server.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az mysql flexible-server start", locals())


def stop(name=None, resource_group=None):
    '''
    Stop a flexible server.

    Optional Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az mysql flexible-server stop", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a flexible server.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az mysql flexible-server delete", locals())


def show(name, resource_group):
    '''
    Get the details of a flexible server.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az mysql flexible-server show", locals())


def list(resource_group=None):
    '''
    List available flexible servers.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az mysql flexible-server list", locals())


def update(name, resource_group, add=None, admin_password=None, backup_retention=None, force_string=None, high_availability=None, iops=None, maintenance_window=None, remove=None, replication_role=None, set=None, sku_name=None, standby_zone=None, storage_auto_grow=None, storage_size=None, tags=None, tier=None):
    '''
    Update a flexible server.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - admin_password -- The password of the administrator. Minimum 8 characters and maximum 128 characters. Password must contain characters from three of the following categories: English uppercase letters, English lowercase letters, numbers, and non-alphanumeric characters.
    - backup_retention -- The number of days a backup is retained. Range of 1 to 35 days. Default is 7 days.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - high_availability -- Enable (ZoneRedundant or SameZone) or disable high availability feature. Default value is Disabled. High availability can only be set during flexible server create time. 
    - iops -- Number of IOPS to be allocated for this server. You will get certain amount of free IOPS based on compute and storage provisioned. The default value for IOPS is free IOPS. To learn more about IOPS based on compute and storage, refer to IOPS in Azure Database for MySQL Flexible Server
    - maintenance_window -- Period of time (UTC) designated for maintenance. Examples: "Sun:23:30" to schedule on Sunday, 11:30pm UTC. To set back to default pass in "Disabled".
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - replication_role -- The replication role of the server.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku_name -- The name of the compute SKU. Follows the convention Standard_{VM name}. Examples: Standard_D4s_v3
    - standby_zone -- The availability zone information of the standby server when high availability is enabled.
    - storage_auto_grow -- Enable or disable autogrow of the storage. Default value is Enabled.
    - storage_size -- The storage capacity of the server. Minimum is 32 GiB and max is 16 TiB.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tier -- Compute tier of the server. Accepted values: Burstable, GeneralPurpose, Memory Optimized 
    '''
    return _call_az("az mysql flexible-server update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for the flexible server to satisfy certain conditions.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az mysql flexible-server wait", locals())


def restart(name, resource_group, failover=None):
    '''
    Restart a flexible server.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - failover -- Forced failover for server restart operation. Allowed values: Forced
    '''
    return _call_az("az mysql flexible-server restart", locals())


def list_skus(location):
    '''
    Lists available sku's in the given region.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az mysql flexible-server list-skus", locals())


def show_connection_string(admin_password=None, admin_user=None, database_name=None, server_name=None):
    '''
    Show the connection strings for a MySQL flexible-server database.

    Optional Parameters:
    - admin_password -- The password of the administrator. Minimum 8 characters and maximum 128 characters. Password must contain characters from three of the following categories: English uppercase letters, English lowercase letters, numbers, and non-alphanumeric characters.
    - admin_user -- Administrator username for the server. Once set, it cannot be changed. 
    - database_name -- The name of the database to be created when provisioning the database server
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    '''
    return _call_az("az mysql flexible-server show-connection-string", locals())




from ... pyaz_utils import _call_az
from . import subscription


def list(no_register=None):
    '''
    List all management groups.

    Optional Parameters:
    - no_register -- Skip registration for resource provider Microsoft.Management
    '''
    return _call_az("az account management-group list", locals())


def show(name, expand=None, no_register=None, recurse=None):
    '''
    Get a specific management group.

    Required Parameters:
    - name -- None

    Optional Parameters:
    - expand -- None
    - no_register -- Skip registration for resource provider Microsoft.Management
    - recurse -- None
    '''
    return _call_az("az account management-group show", locals())


def create(name, display_name=None, no_register=None, parent=None):
    '''
    Create a new management group.

    Required Parameters:
    - name -- None

    Optional Parameters:
    - display_name -- None
    - no_register -- Skip registration for resource provider Microsoft.Management
    - parent -- None
    '''
    return _call_az("az account management-group create", locals())


def delete(name, no_register=None):
    '''
    Delete an existing management group.

    Required Parameters:
    - name -- None

    Optional Parameters:
    - no_register -- Skip registration for resource provider Microsoft.Management
    '''
    return _call_az("az account management-group delete", locals())


def update(name, add=None, display_name=None, force_string=None, parent=None, remove=None, set=None):
    '''
    Update an existing management group.

    Required Parameters:
    - name -- None

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - display_name -- None
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - parent -- None
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az account management-group update", locals())




'''
Manage Batch application packages.
'''
from .... pyaz_utils import _call_az

def create(application_name, name, package_file, resource_group, version_name):
    '''
    Create a Batch application package record and activate it.

    Required Parameters:
    - application_name -- The name of the application.
    - name -- Name of the Batch account.
    - package_file -- The path of the application package in zip format
    - resource_group -- Name of the resource group
    - version_name -- The version name of the application.
    '''
    return _call_az("az batch application package create", locals())


def delete(application_name, name, resource_group, version_name, yes=None):
    '''
    

    Required Parameters:
    - application_name -- The name of the application. This must be unique within the account.
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group
    - version_name -- The version of the application.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batch application package delete", locals())


def show(application_name, name, resource_group, version_name):
    '''
    

    Required Parameters:
    - application_name -- The name of the application. This must be unique within the account.
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group
    - version_name -- The version of the application.
    '''
    return _call_az("az batch application package show", locals())


def activate(application_name, format, name, resource_group, version_name):
    '''
    Activates a Batch application package.

    Required Parameters:
    - application_name -- The name of the application.
    - format -- The format of the application package binary file.
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group
    - version_name -- The version name of the application.
    '''
    return _call_az("az batch application package activate", locals())


def list(application_name, name, resource_group, maxresults=None):
    '''
    

    Required Parameters:
    - application_name -- The name of the application. This must be unique within the account.
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group

    Optional Parameters:
    - maxresults -- The maximum number of items to return in the response.
    '''
    return _call_az("az batch application package list", locals())




'''
Manage Azure Service Bus Rule
'''
from ..... pyaz_utils import _call_az

def create(name, namespace_name, resource_group, subscription_name, topic_name, action_compatibility_level=None, action_sql_expression=None, content_type=None, correlation_id=None, enable_action_preprocessing=None, enable_correlation_preprocessing=None, enable_sql_preprocessing=None, filter_sql_expression=None, label=None, message_id=None, reply_to=None, reply_to_session_id=None, session_id=None, to=None):
    '''
    Create the ServiceBus Rule for Subscription

    Required Parameters:
    - name -- Name of Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subscription_name -- Name of Subscription
    - topic_name -- Name of Topic

    Optional Parameters:
    - action_compatibility_level -- This property is reserved for future use. An integer value showing the compatibility level, currently hard-coded to 20.
    - action_sql_expression -- Action SQL expression.
    - content_type -- Content type of message.
    - correlation_id -- Identifier of correlation.
    - enable_action_preprocessing -- A boolean value that indicates whether the rule action requires preprocessing.
    - enable_correlation_preprocessing -- A boolean value that indicates whether the rule action requires preprocessing.
    - enable_sql_preprocessing -- A boolean value that indicates whether the rule action requires preprocessing.
    - filter_sql_expression -- SQL expression. e.g. myproperty=test
    - label -- Application specific label.
    - message_id -- Identifier of message.
    - reply_to -- Address of the queue to reply to.
    - reply_to_session_id -- Session identifier to reply to.
    - session_id -- Session identifier
    - to -- Address to send to.
    '''
    return _call_az("az servicebus topic subscription rule create", locals())


def show(name, namespace_name, resource_group, subscription_name, topic_name):
    '''
    Shows ServiceBus Rule Details

    Required Parameters:
    - name -- Name of Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subscription_name -- Name of Subscription
    - topic_name -- Name of Topic
    '''
    return _call_az("az servicebus topic subscription rule show", locals())


def list(namespace_name, resource_group, subscription_name, topic_name, skip=None, top=None):
    '''
    List the ServiceBus Rule by Subscription

    Required Parameters:
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subscription_name -- Name of Subscription
    - topic_name -- Name of Topic

    Optional Parameters:
    - skip -- Skip is only used if a previous operation returned a partial result. If a previous response contains a nextLink element, the value of the nextLink element will include a skip parameter that specifies a starting point to use for subsequent calls.
    - top -- May be used to limit the number of results to the most recent N usageDetails.
    '''
    return _call_az("az servicebus topic subscription rule list", locals())


def delete(name, namespace_name, resource_group, subscription_name, topic_name):
    '''
    Deletes the ServiceBus Rule

    Required Parameters:
    - name -- Name of Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subscription_name -- Name of Subscription
    - topic_name -- Name of Topic
    '''
    return _call_az("az servicebus topic subscription rule delete", locals())


def update(name, namespace_name, resource_group, subscription_name, topic_name, action_compatibility_level=None, action_sql_expression=None, add=None, content_type=None, correlation_id=None, enable_action_preprocessing=None, enable_correlation_preprocessing=None, enable_sql_preprocessing=None, filter_sql_expression=None, force_string=None, label=None, message_id=None, remove=None, reply_to=None, reply_to_session_id=None, session_id=None, set=None, to=None):
    '''
    Updates the ServiceBus Rule for Subscription

    Required Parameters:
    - name -- Name of Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subscription_name -- Name of Subscription
    - topic_name -- Name of Topic

    Optional Parameters:
    - action_compatibility_level -- This property is reserved for future use. An integer value showing the compatibility level, currently hard-coded to 20.
    - action_sql_expression -- Action SQL expression.
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - content_type -- Content type of message.
    - correlation_id -- Identifier of correlation.
    - enable_action_preprocessing -- A boolean value that indicates whether the rule action requires preprocessing.
    - enable_correlation_preprocessing -- A boolean value that indicates whether the rule action requires preprocessing.
    - enable_sql_preprocessing -- A boolean value that indicates whether the rule action requires preprocessing.
    - filter_sql_expression -- SQL expression. e.g. myproperty=test
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - label -- Application specific label.
    - message_id -- Identifier of message.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - reply_to -- Address of the queue to reply to.
    - reply_to_session_id -- Session identifier to reply to.
    - session_id -- Session identifier
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - to -- Address to send to.
    '''
    return _call_az("az servicebus topic subscription rule update", locals())




from ... pyaz_utils import _call_az

def set(distribution, name, resource_group):
    '''
    Configure routing traffic to deployment slots.

    Required Parameters:
    - distribution -- space-separated slot routings in a format of `<slot-name>=<percentage>` e.g. staging=50. Unused traffic percentage will go to the Production slot
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az webapp traffic-routing set", locals())


def show(name, resource_group):
    '''
    Display the current distribution of traffic across slots.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az webapp traffic-routing show", locals())


def clear(name, resource_group):
    '''
    Clear the routing rules and send all traffic to production.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az webapp traffic-routing clear", locals())




'''
Find the available VM extensions for a subscription and region.
'''
from .... pyaz_utils import _call_az

def show(location, name, publisher, version):
    '''
    

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Name of the extension
    - publisher -- Image publisher name
    - version -- Extension version
    '''
    return _call_az("az vmss extension image show", locals())


def list_names(location, publisher):
    '''
    

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - publisher -- Image publisher name
    '''
    return _call_az("az vmss extension image list-names", locals())


def list_versions(location, name, publisher, filter=None, orderby=None, top=None):
    '''
    

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Name of the extension
    - publisher -- Image publisher name

    Optional Parameters:
    - filter -- The filter to apply on the operation.
    - orderby -- the $orderby odata query option
    - top -- the $top odata query option
    '''
    return _call_az("az vmss extension image list-versions", locals())


def list(latest=None, location=None, name=None, publisher=None, version=None):
    '''
    List the information on available extensions.

    Optional Parameters:
    - latest -- Show the latest version only.
    - location -- Image location.
    - name -- Image name
    - publisher -- Image publisher name
    - version -- Extension version
    '''
    return _call_az("az vmss extension image list", locals())




'''
Manage Azure Content Delivery Networks (CDNs).
'''
from .. pyaz_utils import _call_az
from . import custom_domain, edge_node, endpoint, origin, origin_group, profile


def name_exists(name):
    '''
    Check the availability of a resource name. This is needed for resources where name is globally unique, such as a CDN endpoint.

    Required Parameters:
    - name -- The resource name to validate.
    '''
    return _call_az("az cdn name-exists", locals())


def usage():
    return _call_az("az cdn usage", locals())




from .... pyaz_utils import _call_az
from . import endpoint, output, test_configuration, test_group


def create(name, dest_address=None, dest_port=None, dest_resource=None, do_not_start=None, endpoint_dest_address=None, endpoint_dest_coverage_level=None, endpoint_dest_name=None, endpoint_dest_resource_id=None, endpoint_dest_type=None, endpoint_source_address=None, endpoint_source_coverage_level=None, endpoint_source_name=None, endpoint_source_resource_id=None, endpoint_source_type=None, frequency=None, http_method=None, http_path=None, http_port=None, http_valid_status_codes=None, https_prefer=None, icmp_disable_trace_route=None, location=None, monitoring_interval=None, notes=None, output_type=None, preferred_ip_version=None, protocol=None, resource_group=None, source_port=None, source_resource=None, tags=None, tcp_disable_trace_route=None, tcp_port=None, tcp_port_behavior=None, test_config_name=None, test_group_disable=None, test_group_name=None, threshold_failed_percent=None, threshold_round_trip_time=None, workspace_ids=None):
    '''
    Create a connection monitor.

    Required Parameters:
    - name -- Connection monitor name.

    Optional Parameters:
    - dest_address -- The IP address or URI at which to receive traffic.
    - dest_port -- Port number on which to receive traffic.
    - dest_resource -- Name of ID of the resource to receive traffic. Currently only Virtual Machines are supported.
    - do_not_start -- Create the connection monitor but do not start it immediately.
    - endpoint_dest_address -- Address of the destination of connection monitor endpoint (IP or domain name)
    - endpoint_dest_coverage_level -- Test coverage for the endpoint
    - endpoint_dest_name -- The name of the destination of connection monitor endpoint. If you are creating a V2 Connection Monitor, it's required
    - endpoint_dest_resource_id -- Resource ID of the destination of connection monitor endpoint
    - endpoint_dest_type -- The endpoint type
    - endpoint_source_address -- Address of the source of connection monitor endpoint (IP or domain name)
    - endpoint_source_coverage_level -- Test coverage for the endpoint
    - endpoint_source_name -- The name of the source of connection monitor endpoint. If you are creating a V2 Connection Monitor, it's required
    - endpoint_source_resource_id -- Resource ID of the source of connection monitor endpoint. If endpoint is intended to used as source, this option is required.
    - endpoint_source_type -- The endpoint type
    - frequency -- The frequency of test evaluation, in seconds
    - http_method -- The HTTP method to use
    - http_path -- The path component of the URI. For instance, "/dir1/dir2"
    - http_port -- The port to connect to
    - http_valid_status_codes -- Space-separated list of HTTP status codes to consider successful. For instance, "2xx 301-304 418"
    - https_prefer -- Value indicating whether HTTPS is preferred over HTTP in cases where the choice is not explicit
    - icmp_disable_trace_route -- Value indicating whether path evaluation with trace route should be disabled. false is default.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - monitoring_interval -- Monitoring interval in seconds.
    - notes -- Optional notes to be associated with the connection monitor
    - output_type -- Connection monitor output destination type. Currently, only "Workspace" is supported
    - preferred_ip_version -- The preferred IP version to use in test evaluation. The connection monitor may choose to use a different version depending on other parameters
    - protocol -- The protocol to use in test evaluation
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source_port -- Port number from which to originate traffic.
    - source_resource -- Name or ID of the resource from which to originate traffic. Currently only Virtual Machines are supported.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tcp_disable_trace_route -- Value indicating whether path evaluation with trace route should be disabled. false is default.
    - tcp_port -- The port to connect to
    - tcp_port_behavior -- Destination port behavior
    - test_config_name -- The name of the connection monitor test configuration. If you are creating a V2 Connection Monitor, it's required
    - test_group_disable -- Value indicating whether test group is disabled. false is default.
    - test_group_name -- The name of the connection monitor test group
    - threshold_failed_percent -- The maximum percentage of failed checks permitted for a test to evaluate as successful
    - threshold_round_trip_time -- The maximum round-trip time in milliseconds permitted for a test to evaluate as successful
    - workspace_ids -- Space-separated list of ids of log analytics workspace
    '''
    return _call_az("az network watcher connection-monitor create", locals())


def delete(location, name, resource_group=None):
    '''
    Delete a connection monitor for the given region.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Connection monitor name.

    Optional Parameters:
    - resource_group -- ==SUPPRESS==
    '''
    return _call_az("az network watcher connection-monitor delete", locals())


def show(location, name, resource_group=None):
    '''
    Shows a connection monitor by name.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Connection monitor name.

    Optional Parameters:
    - resource_group -- ==SUPPRESS==
    '''
    return _call_az("az network watcher connection-monitor show", locals())


def stop(location, name, resource_group=None):
    '''
    Stop the specified connection monitor.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Connection monitor name.

    Optional Parameters:
    - resource_group -- ==SUPPRESS==
    '''
    return _call_az("az network watcher connection-monitor stop", locals())


def start(location, name, resource_group=None):
    '''
    Start the specified connection monitor.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Connection monitor name.

    Optional Parameters:
    - resource_group -- ==SUPPRESS==
    '''
    return _call_az("az network watcher connection-monitor start", locals())


def query(location, name, resource_group=None):
    '''
    Query a snapshot of the most recent connection state of a connection monitor.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Connection monitor name.

    Optional Parameters:
    - resource_group -- ==SUPPRESS==
    '''
    return _call_az("az network watcher connection-monitor query", locals())


def list(location, resource_group=None):
    '''
    List connection monitors for the given region.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.

    Optional Parameters:
    - resource_group -- ==SUPPRESS==
    '''
    return _call_az("az network watcher connection-monitor list", locals())




from .... pyaz_utils import _call_az
from . import identity, link, location


def create(name, resource_group, bandwidth=None, encapsulation=None, location=None, peering_location=None, tags=None):
    '''
    Create an ExpressRoute port.

    Required Parameters:
    - name -- ExpressRoute port name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - bandwidth -- Bandwidth of the circuit. Usage: INT {Mbps,Gbps}. Defaults to Gbps
    - encapsulation -- Encapsulation method on physical ports.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - peering_location -- The name of the peering location that the port is mapped to physically.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network express-route port create", locals())


def delete(name, resource_group):
    '''
    Delete an ExpressRoute port.

    Required Parameters:
    - name -- ExpressRoute port name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route port delete", locals())


def list(resource_group=None):
    '''
    List ExpressRoute ports.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route port list", locals())


def show(name, resource_group):
    '''
    Get the details of an ExpressRoute port.

    Required Parameters:
    - name -- ExpressRoute port name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route port show", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update settings of an ExpressRoute port.

    Required Parameters:
    - name -- ExpressRoute port name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network express-route port update", locals())


def generate_loa(customer_name, name, resource_group, file=None):
    '''
    Generate and download a letter of authorization for the requested ExpressRoutePort

    Required Parameters:
    - customer_name -- The customer name
    - name -- ExpressRoute port name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - file -- Directory or the file path of the letter to be saved to. If the file name extension is not .pdf, Azure CLI will help to append. Be careful, the existing file might get overwritten
    '''
    return _call_az("az network express-route port generate-loa", locals())




'''
Manage budgets for an Azure subscription.
'''
from ... pyaz_utils import _call_az

def list(resource_group=None):
    '''
    List budgets for an Azure subscription.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az consumption budget list", locals())


def show(budget_name, resource_group=None):
    '''
    Show budget for an Azure subscription.

    Required Parameters:
    - budget_name -- Name of a budget.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az consumption budget show", locals())


def create(amount, budget_name, category, end_date, start_date, time_grain, meter_filter=None, resource_filter=None, resource_group=None, resource_group_filter=None):
    '''
    Create a budget for an Azure subscription.

    Required Parameters:
    - amount -- Amount of a budget.
    - budget_name -- Name of a budget.
    - category -- Category of the budget can be cost or usage.
    - end_date -- End date (YYYY-MM-DD in UTC) of time period of a budget.
    - start_date -- Start date (YYYY-MM-DD in UTC) of time period of a budget.
    - time_grain -- Time grain of the budget can be monthly, quarterly, or annually.

    Optional Parameters:
    - meter_filter -- Space-separated list of meters to filter on. Required if category is usage.
    - resource_filter -- Space-separated list of resource instances to filter on.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_group_filter -- Space-separated list of resource groups to filter on.
    '''
    return _call_az("az consumption budget create", locals())


def delete(budget_name, resource_group=None):
    '''
    Delete a budget for an Azure subscription.

    Required Parameters:
    - budget_name -- Name of a budget.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az consumption budget delete", locals())




'''
Manage Azure Managed Disks.
'''
from .. pyaz_utils import _call_az

def create(name, resource_group, accelerated_network=None, disk_access=None, disk_encryption_set=None, disk_iops_read_only=None, disk_iops_read_write=None, disk_mbps_read_only=None, disk_mbps_read_write=None, edge_zone=None, enable_bursting=None, encryption_type=None, for_upload=None, gallery_image_reference=None, gallery_image_reference_lun=None, hyper_v_generation=None, image_reference=None, image_reference_lun=None, location=None, logical_sector_size=None, max_shares=None, network_access_policy=None, no_wait=None, os_type=None, public_network_access=None, security_type=None, size_gb=None, sku=None, source=None, source_storage_account_id=None, support_hibernation=None, tags=None, tier=None, upload_size_bytes=None, zone=None):
    '''
    Create a managed disk.

    Required Parameters:
    - name -- The name of the managed disk
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - accelerated_network -- Customers can set on Managed Disks or Snapshots to enable the accelerated networking if the OS disk image support.
    - disk_access -- Name or ID of the disk access resource for using private endpoints on disks.
    - disk_encryption_set -- Name or ID of disk encryption set that is used to encrypt the disk.
    - disk_iops_read_only -- The total number of IOPS that will be allowed across all VMs mounting the shared disk as ReadOnly. One operation can transfer between 4k and 256k bytes
    - disk_iops_read_write -- The number of IOPS allowed for this disk. Only settable for UltraSSD disks. One operation can transfer between 4k and 256k bytes
    - disk_mbps_read_only -- The total throughput (MBps) that will be allowed across all VMs mounting the shared disk as ReadOnly. MBps means millions of bytes per second - MB here uses the ISO notation, of powers of 10
    - disk_mbps_read_write -- The bandwidth allowed for this disk. Only settable for UltraSSD disks. MBps means millions of bytes per second with ISO notation of powers of 10
    - edge_zone -- The name of edge zone.
    - enable_bursting -- Enable bursting beyond the provisioned performance target of the disk. Bursting is disabled by default, and it does not apply to Ultra disks.
    - encryption_type -- Encryption type. EncryptionAtRestWithPlatformKey: Disk is encrypted with XStore managed key at rest. It is the default encryption type. EncryptionAtRestWithCustomerKey: Disk is encrypted with Customer managed key at rest.
    - for_upload -- Create the disk for uploading blobs later on through storage commands. Run "az disk grant-access --access-level Write" to retrieve the disk's SAS token.
    - gallery_image_reference -- ID of the Compute Gallery image version from which to create a disk
    - gallery_image_reference_lun -- If the disk is created from an image's data disk, this is an index that indicates which of the data disks in the image to use. For OS disks, this field is null
    - hyper_v_generation -- The hypervisor generation of the Virtual Machine. Applicable to OS disks only.
    - image_reference -- ID or URN (publisher:offer:sku:version) of the image from which to create a disk
    - image_reference_lun -- If the disk is created from an image's data disk, this is an index that indicates which of the data disks in the image to use. For OS disks, this field is null
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`. If location is not specified and no default location specified, location will be automatically set as same as the resource group.
    - logical_sector_size -- Logical sector size in bytes for Ultra disks. Supported values are 512 ad 4096. 4096 is the default.
    - max_shares -- The maximum number of VMs that can attach to the disk at the same time. Value greater than one indicates a disk that can be mounted on multiple VMs at the same time
    - network_access_policy -- Policy for accessing the disk via network.
    - no_wait -- Do not wait for the long-running operation to finish.
    - os_type -- The Operating System type of the Disk.
    - public_network_access -- Customers can set on Managed Disks or Snapshots to control the export policy on the disk.
    - security_type -- The security type of the VM. Applicable for OS disks only.
    - size_gb -- size in GB. Max size: 4095 GB (certain preview disks can be larger).
    - sku -- Underlying storage SKU
    - source -- source to create the disk/snapshot from, including unmanaged blob uri, managed disk id or name, or snapshot id or name
    - source_storage_account_id -- used when source blob is in a different subscription
    - support_hibernation -- Indicate the OS on a disk supports hibernation.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tier -- Performance tier of the disk (e.g, P4, S10) as described here: https://azure.microsoft.com/pricing/details/managed-disks/. Does not apply to Ultra disks.
    - upload_size_bytes -- The size (in bytes) of the contents of the upload including the VHD footer. Min value: 20972032. Max value: 35183298347520
    - zone -- Availability zone into which to provision the resource.
    '''
    return _call_az("az disk create", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete a managed disk.

    Required Parameters:
    - name -- The name of the managed disk
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az disk delete", locals())


def grant_access(duration_in_seconds, name, resource_group, access_level=None):
    '''
    Grant a resource access to a managed disk.

    Required Parameters:
    - duration_in_seconds -- Time duration in seconds until the SAS access expires
    - name -- The name of the managed disk
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - access_level -- access level
    '''
    return _call_az("az disk grant-access", locals())


def list(resource_group=None):
    '''
    List managed disks.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az disk list", locals())


def revoke_access(name, resource_group):
    '''
    Revoke a resource's read access to a managed disk.

    Required Parameters:
    - name -- The name of the managed disk
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az disk revoke-access", locals())


def show(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the managed disk
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az disk show", locals())


def update(name, resource_group, accelerated_network=None, add=None, disk_access=None, disk_encryption_set=None, disk_iops_read_only=None, disk_iops_read_write=None, disk_mbps_read_only=None, disk_mbps_read_write=None, enable_bursting=None, encryption_type=None, force_string=None, max_shares=None, network_access_policy=None, no_wait=None, public_network_access=None, remove=None, set=None, size_gb=None, sku=None):
    '''
    Update a managed disk.

    Required Parameters:
    - name -- The name of the managed disk
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - accelerated_network -- Customers can set on Managed Disks or Snapshots to enable the accelerated networking if the OS disk image support.
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - disk_access -- Name or ID of the disk access resource for using private endpoints on disks.
    - disk_encryption_set -- Name or ID of disk encryption set that is used to encrypt the disk.
    - disk_iops_read_only -- The total number of IOPS that will be allowed across all VMs mounting the shared disk as ReadOnly. One operation can transfer between 4k and 256k bytes
    - disk_iops_read_write -- The number of IOPS allowed for this disk. Only settable for UltraSSD disks. One operation can transfer between 4k and 256k bytes
    - disk_mbps_read_only -- The total throughput (MBps) that will be allowed across all VMs mounting the shared disk as ReadOnly. MBps means millions of bytes per second - MB here uses the ISO notation, of powers of 10
    - disk_mbps_read_write -- The bandwidth allowed for this disk. Only settable for UltraSSD disks. MBps means millions of bytes per second with ISO notation of powers of 10
    - enable_bursting -- Enable bursting beyond the provisioned performance target of the disk. Bursting is disabled by default, and it does not apply to Ultra disks.
    - encryption_type -- Encryption type. EncryptionAtRestWithPlatformKey: Disk is encrypted with XStore managed key at rest. It is the default encryption type. EncryptionAtRestWithCustomerKey: Disk is encrypted with Customer managed key at rest.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - max_shares -- The maximum number of VMs that can attach to the disk at the same time. Value greater than one indicates a disk that can be mounted on multiple VMs at the same time
    - network_access_policy -- Policy for accessing the disk via network.
    - no_wait -- Do not wait for the long-running operation to finish.
    - public_network_access -- Customers can set on Managed Disks or Snapshots to control the export policy on the disk.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - size_gb -- size in GB. Max size: 4095 GB (certain preview disks can be larger).
    - sku -- Underlying storage SKU
    '''
    return _call_az("az disk update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a managed disk is met.

    Required Parameters:
    - name -- The name of the managed disk
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az disk wait", locals())




from ..... pyaz_utils import _call_az
from . import ipv6_config


def create(address_prefix, circuit_name, name, peer_circuit, peering_name, resource_group, authorization_key=None):
    '''
    Create connections between two ExpressRoute circuits.

    Required Parameters:
    - address_prefix -- /29 IP address space to carve out customer addresses for tunnels.
    - circuit_name -- ExpressRoute circuit name.
    - name -- Name of the peering connection.
    - peer_circuit -- Name or ID of the peer ExpressRoute circuit.
    - peering_name -- Name of BGP peering (i.e. AzurePrivatePeering).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - authorization_key -- The authorization key used when the peer circuit is in another subscription.
    '''
    return _call_az("az network express-route peering connection create", locals())


def delete(circuit_name, name, peering_name, resource_group):
    '''
    Delete an ExpressRoute circuit connection.

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - name -- Name of the peering connection.
    - peering_name -- Name of BGP peering (i.e. AzurePrivatePeering).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route peering connection delete", locals())


def show(circuit_name, name, peering_name, resource_group):
    '''
    Get the details of an ExpressRoute circuit connection.

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - name -- Name of the peering connection.
    - peering_name -- Name of BGP peering (i.e. AzurePrivatePeering).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route peering connection show", locals())


def list(circuit_name, peering_name, resource_group):
    '''
    List all global reach connections associated with a private peering in an express route circuit.

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - peering_name -- Name of BGP peering (i.e. AzurePrivatePeering).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route peering connection list", locals())




from ... pyaz_utils import _call_az
from . import address_pool, auth_cert, client_cert, frontend_ip, frontend_port, http_listener, http_settings, identity, private_link, probe, redirect_config, root_cert, rule, ssl_cert, ssl_policy, ssl_profile, url_path_map, waf_config, waf_policy


def create(name, resource_group, capacity=None, cert_file=None, cert_password=None, connection_draining_timeout=None, custom_error_pages=None, enable_private_link=None, frontend_port=None, http2=None, http_settings_cookie_based_affinity=None, http_settings_port=None, http_settings_protocol=None, identity=None, key_vault_secret_id=None, location=None, max_capacity=None, min_capacity=None, no_wait=None, private_ip_address=None, private_link_ip_address=None, private_link_primary=None, private_link_subnet=None, private_link_subnet_prefix=None, public_ip_address=None, public_ip_address_allocation=None, routing_rule_type=None, servers=None, sku=None, ssl_certificate_name=None, ssl_profile=None, ssl_profile_id=None, subnet=None, subnet_address_prefix=None, tags=None, trusted_client_cert=None, validate=None, vnet_address_prefix=None, vnet_name=None, waf_policy=None, zones=None):
    '''
    Create an application gateway.

    Required Parameters:
    - name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - capacity -- The number of instances to use with the application gateway.
    - cert_file -- The path to the PFX certificate file.
    - cert_password -- The certificate password
    - connection_draining_timeout -- The time in seconds after a backend server is removed during which on open connection remains active. Range: 0 (disabled) to 3600
    - custom_error_pages -- Space-separated list of custom error pages in `STATUS_CODE=URL` format.
    - enable_private_link -- Enable Private Link feature for this application gateway. If both public IP and private IP are enbaled, taking effect only in public frontend IP
    - frontend_port -- The front end port number.
    - http2 -- Use HTTP2 for the application gateway.
    - http_settings_cookie_based_affinity -- Enable or disable HTTP settings cookie-based affinity.
    - http_settings_port -- The HTTP settings port.
    - http_settings_protocol -- The HTTP settings protocol.
    - identity -- Name or ID of the ManagedIdentity Resource
    - key_vault_secret_id -- Secret Id of (base-64 encoded unencrypted pfx) 'Secret' or 'Certificate' object stored in Azure KeyVault. You need enable soft delete for keyvault to use this feature.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - max_capacity -- Upper bound on the number of application gateway instances.
    - min_capacity -- Lower bound on the number of application gateway instances.
    - no_wait -- Do not wait for the long-running operation to finish.
    - private_ip_address -- Static private IP address to use.
    - private_link_ip_address -- The static private IP address of a subnet for Private Link. If omitting, a dynamic one will be created
    - private_link_primary -- Whether the IP configuration is primary or not
    - private_link_subnet -- The name of the subnet within the same vnet of an application gateway
    - private_link_subnet_prefix -- The CIDR prefix to use when creating a new subnet
    - public_ip_address -- Name or ID of a public IP address. Uses existing resource or creates new if specified, or none if omitted.
    - public_ip_address_allocation -- The kind of IP allocation to use when creating a new public IP.
    - routing_rule_type -- The request routing rule type.
    - servers -- Space-separated list of IP addresses or DNS names corresponding to backend servers.
    - sku -- The name of the SKU.
    - ssl_certificate_name -- The certificate name. Default will be `<application-gateway-name>SslCert`.
    - ssl_profile -- None
    - ssl_profile_id -- SSL profile resource of the application gateway.
    - subnet -- Name or ID of the subnet. Will create resource if it does not exist. If name specified, also specify --vnet-name. If you want to use an existing subnet in other resource group or subscription, please provide the ID instead of the name of the subnet
    - subnet_address_prefix -- The CIDR prefix to use when creating a new subnet.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - trusted_client_cert -- None
    - validate -- Generate and validate the ARM template without creating any resources.
    - vnet_address_prefix -- The CIDR prefix to use when creating a new VNet.
    - vnet_name -- The virtual network (VNet) name.
    - waf_policy -- Name or ID of a web application firewall (WAF) policy.
    - zones -- Space-separated list of availability zones into which to provision the resource.
    '''
    return _call_az("az network application-gateway create", locals())


def delete(name, resource_group, no_wait=None):
    '''
    Delete an application gateway.

    Required Parameters:
    - name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network application-gateway delete", locals())


def show(name, resource_group):
    '''
    Get the details of an application gateway.

    Required Parameters:
    - name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway show", locals())


def list(resource_group=None):
    '''
    List application gateways.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway list", locals())


def start(name, resource_group):
    '''
    Start an application gateway.

    Required Parameters:
    - name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway start", locals())


def stop(name, resource_group):
    '''
    Stop an application gateway.

    Required Parameters:
    - name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway stop", locals())


def show_backend_health(name, resource_group, address_pool=None, expand=None, host=None, host_name_from_http_settings=None, http_settings=None, match_body=None, match_status_codes=None, path=None, protocol=None, timeout=None):
    '''
    Get information on the backend health of an application gateway.

    Required Parameters:
    - name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - address_pool -- The name or ID of the backend address pool.
    - expand -- Expands BackendAddressPool and BackendHttpSettings referenced in backend health.
    - host -- The name of the host to send the probe.
    - host_name_from_http_settings -- Use host header from HTTP settings.
    - http_settings -- The name or ID of the HTTP settings.
    - match_body -- Body that must be contained in the health response.
    - match_status_codes -- Space-separated list of allowed ranges of healthy status codes for the health response.
    - path -- The relative path of the probe. Valid paths start from "/"
    - protocol -- The HTTP settings protocol.
    - timeout -- The probe timeout in seconds.
    '''
    return _call_az("az network application-gateway show-backend-health", locals())


def update(name, resource_group, add=None, capacity=None, custom_error_pages=None, force_string=None, http2=None, max_capacity=None, min_capacity=None, no_wait=None, remove=None, set=None, sku=None, tags=None):
    '''
    Update an application gateway.

    Required Parameters:
    - name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - capacity -- The number of instances to use with the application gateway.
    - custom_error_pages -- Space-separated list of custom error pages in `STATUS_CODE=URL` format.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - http2 -- Use HTTP2 for the application gateway.
    - max_capacity -- Upper bound on the number of application gateway instances.
    - min_capacity -- Lower bound on the number of application gateway instances.
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku -- The name of the SKU.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network application-gateway update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the application gateway is met.

    Required Parameters:
    - name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az network application-gateway wait", locals())




from .... pyaz_utils import _call_az

def check_dns(name, type=None):
    '''
    Check the availability of a relative DNS name.

    Required Parameters:
    - name -- DNS prefix to verify availability for.

    Optional Parameters:
    - type -- ==SUPPRESS==
    '''
    return _call_az("az network traffic-manager profile check-dns", locals())


def show(name, resource_group):
    '''
    Get the details of a traffic manager profile.

    Required Parameters:
    - name -- The name of the Traffic Manager profile.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network traffic-manager profile show", locals())


def delete(name, resource_group):
    '''
    Delete a traffic manager profile.

    Required Parameters:
    - name -- The name of the Traffic Manager profile to be deleted.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network traffic-manager profile delete", locals())


def list(resource_group=None):
    '''
    List traffic manager profiles.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network traffic-manager profile list", locals())


def create(name, resource_group, routing_method, unique_dns_name, custom_headers=None, interval=None, max_failures=None, max_return=None, path=None, port=None, protocol=None, status=None, status_code_ranges=None, tags=None, timeout=None, ttl=None):
    '''
    Create a traffic manager profile.

    Required Parameters:
    - name -- Traffic manager profile name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - routing_method -- Routing method.
    - unique_dns_name -- Relative DNS name for the traffic manager profile. Resulting FQDN will be `<unique-dns-name>.trafficmanager.net` and must be globally unique.

    Optional Parameters:
    - custom_headers -- Space-separated list of NAME=VALUE pairs.
    - interval -- The interval in seconds at which health checks are conducted.
    - max_failures -- The number of consecutive failed health checks tolerated before an endpoint is considered degraded.
    - max_return -- Maximum number of endpoints to be returned for MultiValue routing type.
    - path -- Path to monitor. Use ""('""' in PowerShell) for none.
    - port -- Port to monitor.
    - protocol -- Monitor protocol.
    - status -- Status of the Traffic Manager profile.
    - status_code_ranges -- Space-separated list of status codes in MIN-MAX or VAL format.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - timeout -- The time in seconds allowed for endpoints to respond to a health check.
    - ttl -- DNS config time-to-live in seconds.
    '''
    return _call_az("az network traffic-manager profile create", locals())


def update(name, resource_group, add=None, custom_headers=None, force_string=None, interval=None, max_failures=None, max_return=None, path=None, port=None, protocol=None, remove=None, routing_method=None, set=None, status=None, status_code_ranges=None, tags=None, timeout=None, ttl=None):
    '''
    Update a traffic manager profile.

    Required Parameters:
    - name -- The name of the Traffic Manager profile.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - custom_headers -- Space-separated list of NAME=VALUE pairs.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - interval -- The interval in seconds at which health checks are conducted.
    - max_failures -- The number of consecutive failed health checks tolerated before an endpoint is considered degraded.
    - max_return -- Maximum number of endpoints to be returned for MultiValue routing type.
    - path -- Path to monitor. Use ""('""' in PowerShell) for none.
    - port -- Port to monitor.
    - protocol -- Monitor protocol.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - routing_method -- Routing method.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - status -- Status of the Traffic Manager profile.
    - status_code_ranges -- Space-separated list of status codes in MIN-MAX or VAL format.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - timeout -- The time in seconds allowed for endpoints to respond to a health check.
    - ttl -- DNS config time-to-live in seconds.
    '''
    return _call_az("az network traffic-manager profile update", locals())




from ... pyaz_utils import _call_az

def create(cluster_name, delegated_management_subnet_id, location, resource_group, authentication_method=None, cassandra_version=None, client_certificates=None, cluster_name_override=None, external_gossip_certificates=None, external_seed_nodes=None, hours_between_backups=None, identity_type=None, initial_cassandra_admin_password=None, no_wait=None, repair_enabled=None, restore_from_backup_id=None, tags=None):
    '''
    Create a Managed Cassandra Cluster.

    Required Parameters:
    - cluster_name -- Cluster Name
    - delegated_management_subnet_id -- The resource id of a subnet where the ip address of the cassandra management server will be allocated. This subnet must have connectivity to the delegated_subnet_id subnet of each data center.
    - location -- Azure Location of the Cluster
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - authentication_method -- Authentication mode can be None or Cassandra. If None, no authentication will be required to connect to the Cassandra API. If Cassandra, then passwords will be used.
    - cassandra_version -- The version of Cassandra chosen.
    - client_certificates -- If specified, enables client certificate authentication to the Cassandra API.
    - cluster_name_override -- If a cluster must have a name that is not a valid azure resource name, this field can be specified to choose the Cassandra cluster name. Otherwise, the resource name will be used as the cluster name.
    - external_gossip_certificates -- A list of certificates that the managed cassandra data center's should accept.
    - external_seed_nodes -- A list of ip addresses of the seed nodes of on-premise data centers.
    - hours_between_backups -- The number of hours between backup attempts.
    - identity_type -- Type of identity used for Customer Managed Disk Key.
    - initial_cassandra_admin_password -- The intial password to be configured when a cluster is created for authentication_method Cassandra.
    - no_wait -- Do not wait for the long-running operation to finish.
    - repair_enabled -- Enables automatic repair.
    - restore_from_backup_id -- The resource id of a backup. If provided on create, the backup will be used to prepopulate the cluster. The cluster data center count and node counts must match the backup.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az managed-cassandra cluster create", locals())


def update(cluster_name, resource_group, authentication_method=None, cassandra_version=None, client_certificates=None, external_gossip_certificates=None, external_seed_nodes=None, hours_between_backups=None, identity_type=None, no_wait=None, repair_enabled=None, tags=None):
    '''
    Update a Managed Cassandra Cluster.

    Required Parameters:
    - cluster_name -- Cluster Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - authentication_method -- Authentication mode can be None or Cassandra. If None, no authentication will be required to connect to the Cassandra API. If Cassandra, then passwords will be used.
    - cassandra_version -- The version of Cassandra chosen.
    - client_certificates -- If specified, enables client certificate authentication to the Cassandra API.
    - external_gossip_certificates -- A list of certificates that the managed cassandra data center's should accept.
    - external_seed_nodes -- A list of ip addresses of the seed nodes of on-premise data centers.
    - hours_between_backups -- The number of hours between backup attempts.
    - identity_type -- Type of identity used for Customer Managed Disk Key.
    - no_wait -- Do not wait for the long-running operation to finish.
    - repair_enabled -- Enables automatic repair.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az managed-cassandra cluster update", locals())


def deallocate(cluster_name, resource_group, no_wait=None):
    '''
    Deallocate the Managed Cassandra Cluster and Associated Data Centers. Deallocation will deallocate the host virtual machine of this cluster, and reserved the data disk. This won't do anything on an already deallocated cluster. Use Start to restart the cluster.

    Required Parameters:
    - cluster_name -- Cluster Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az managed-cassandra cluster deallocate", locals())


def invoke_command(cluster_name, command_name, host, resource_group, arguments=None, cassandra_stop_start=None, no_wait=None, readwrite=None):
    '''
    Invoke a command like nodetool for cassandra maintenance.

    Required Parameters:
    - cluster_name -- Cluster Name
    - command_name -- The command which should be run
    - host -- IP address of the cassandra host to run the command on
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - arguments -- The key="value" of arguments for the command.
    - cassandra_stop_start -- If true, stops cassandra before executing the command and then start it again.
    - no_wait -- Do not wait for the long-running operation to finish.
    - readwrite -- If true, allows the command to *write* to the cassandra directory, otherwise read-only.
    '''
    return _call_az("az managed-cassandra cluster invoke-command", locals())


def start(cluster_name, resource_group, no_wait=None):
    '''
    Start the Managed Cassandra Cluster and Associated Data Centers. Start will start the host virtual machine of this cluster with reserved data disk. This won't do anything on an already running cluster. Use Deallocate to deallocate the cluster.

    Required Parameters:
    - cluster_name -- Cluster Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az managed-cassandra cluster start", locals())


def status(cluster_name, resource_group):
    '''
    Gets the CPU, memory, and disk usage statistics for each Cassandra node in a cluster.

    Required Parameters:
    - cluster_name -- Cluster Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az managed-cassandra cluster status", locals())


def list(resource_group=None):
    '''
    List the Managed Cassandra Clusters in a ResourceGroup and Subscription. If the ResourceGroup is not specified all the clusters in this Subscription are returned.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az managed-cassandra cluster list", locals())


def show(cluster_name, resource_group):
    '''
    Get a Managed Cassandra Cluster Resource.

    Required Parameters:
    - cluster_name -- Cluster Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az managed-cassandra cluster show", locals())


def delete(cluster_name, resource_group, no_wait=None, yes=None):
    '''
    Deletes a Managed Cassandra Cluster.

    Required Parameters:
    - cluster_name -- Cluster Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az managed-cassandra cluster delete", locals())




from .... pyaz_utils import _call_az

def show(name, resource_group, server):
    '''
    Show the current ledger digest settings.

    Required Parameters:
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql db ledger-digest-uploads show", locals())


def enable(endpoint, name, resource_group, server):
    '''
    Enable uploading ledger digests to an Azure Storage account or to Azure Confidential Ledger. If uploading ledger digests is already enabled, the cmdlet resets the digest storage endpoint to a new value.

    Required Parameters:
    - endpoint -- The endpoint of a digest storage, which can be either an Azure Blob storage or a ledger in Azure Confidential Ledger.
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql db ledger-digest-uploads enable", locals())


def disable(name, resource_group, server):
    '''
    Disable uploading ledger digests.

    Required Parameters:
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql db ledger-digest-uploads disable", locals())




'''
List billing permissions
'''
from ... pyaz_utils import _call_az

def list(account_name, customer_name=None, invoice_section_name=None, profile_name=None):
    '''
    List the billing permissions the caller has on a billing account.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.

    Optional Parameters:
    - customer_name -- The ID that uniquely identifies a customer.
    - invoice_section_name -- The ID that uniquely identifies an invoice section.
    - profile_name -- The ID that uniquely identifies a billing profile.
    '''
    return _call_az("az billing permission list", locals())




from ... pyaz_utils import _call_az
from . import address_pool, frontend_ip, probe, rule


def show(name, resource_group, expand=None):
    '''
    

    Required Parameters:
    - name -- The load balancer name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- Expands referenced resources.
    '''
    return _call_az("az network cross-region-lb show", locals())


def create(name, resource_group, backend_pool_name=None, frontend_ip_name=None, frontend_ip_zone=None, location=None, no_wait=None, public_ip_address=None, public_ip_address_allocation=None, public_ip_dns_name=None, public_ip_zone=None, tags=None, validate=None):
    '''
    Create a cross-region load balancer.

    Required Parameters:
    - name -- The load balancer name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - backend_pool_name -- The name of the backend address pool.
    - frontend_ip_name -- The name of the frontend IP configuration.
    - frontend_ip_zone -- used to create internal facing Load balancer
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - public_ip_address -- Name or ID of the public IP address, or '' for none. Uses existing resource if available or will create a new resource with defaults if omitted.
    - public_ip_address_allocation -- IP allocation method.
    - public_ip_dns_name -- Globally unique DNS name for a new public IP.
    - public_ip_zone -- used to created a new public ip for the load balancer, a.k.a public facing Load balancer
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - validate -- Generate and validate the ARM template without creating any resources.
    '''
    return _call_az("az network cross-region-lb create", locals())


def delete(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The load balancer name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network cross-region-lb delete", locals())


def list(resource_group=None):
    '''
    List load balancers.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network cross-region-lb list", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update a cross-region load balancer.

    Required Parameters:
    - name -- The load balancer name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network cross-region-lb update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the cross-region load balancer is met.

    Required Parameters:
    - name -- The load balancer name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - expand -- Expands referenced resources.
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az network cross-region-lb wait", locals())




from .... pyaz_utils import _call_az
from . import condition, set


def create(gateway_name, name, resource_group, rule_set_name, enable_reroute=None, modified_path=None, modified_query_string=None, no_wait=None, request_headers=None, response_headers=None, sequence=None):
    '''
    Create a rewrite rule.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- Name of the rewrite rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_name -- Name of the rewrite rule set.

    Optional Parameters:
    - enable_reroute -- If set as true, it will re-evaluate the url path map provided in path based request routing rules using modified path.
    - modified_path -- Url path for url rewrite
    - modified_query_string -- Query string for url rewrite.
    - no_wait -- Do not wait for the long-running operation to finish.
    - request_headers -- Space-separated list of HEADER=VALUE pairs.
    - response_headers -- Space-separated list of HEADER=VALUE pairs.
    - sequence -- Determines the execution order of the rule in the rule set.
    '''
    return _call_az("az network application-gateway rewrite-rule create", locals())


def show(gateway_name, name, resource_group, rule_set_name):
    '''
    Get the details of a rewrite rule.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- Name of the rewrite rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_name -- Name of the rewrite rule set.
    '''
    return _call_az("az network application-gateway rewrite-rule show", locals())


def list(gateway_name, resource_group, rule_set_name):
    '''
    List rewrite rules.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_name -- Name of the rewrite rule set.
    '''
    return _call_az("az network application-gateway rewrite-rule list", locals())


def delete(gateway_name, name, resource_group, rule_set_name, no_wait=None):
    '''
    Delete a rewrite rule.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- Name of the rewrite rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_name -- Name of the rewrite rule set.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network application-gateway rewrite-rule delete", locals())


def update(gateway_name, name, resource_group, rule_set_name, add=None, enable_reroute=None, force_string=None, modified_path=None, modified_query_string=None, no_wait=None, remove=None, request_headers=None, response_headers=None, sequence=None, set=None):
    '''
    Update a rewrite rule.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- Name of the rewrite rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_name -- Name of the rewrite rule set.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - enable_reroute -- If set as true, it will re-evaluate the url path map provided in path based request routing rules using modified path.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - modified_path -- Url path for url rewrite
    - modified_query_string -- Query string for url rewrite.
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - request_headers -- Space-separated list of HEADER=VALUE pairs.
    - response_headers -- Space-separated list of HEADER=VALUE pairs.
    - sequence -- Determines the execution order of the rule in the rule set.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network application-gateway rewrite-rule update", locals())


def list_request_headers():
    return _call_az("az network application-gateway rewrite-rule list-request-headers", locals())


def list_response_headers():
    return _call_az("az network application-gateway rewrite-rule list-response-headers", locals())




from ... pyaz_utils import _call_az

def list(workspace_name):
    '''
    List spark job definitions.

    Required Parameters:
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse spark-job-definition list", locals())


def show(name, workspace_name):
    '''
    Get a spark job definition.

    Required Parameters:
    - name -- The spark job definition name
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse spark-job-definition show", locals())


def delete(name, workspace_name, no_wait=None):
    '''
    Delete a spark job definition.

    Required Parameters:
    - name -- The spark job definition name
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse spark-job-definition delete", locals())


def create(file, name, workspace_name, folder_path=None, no_wait=None):
    '''
    Create a spark job definition.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The spark job definition name
    - workspace_name -- The workspace name.

    Optional Parameters:
    - folder_path -- The folder that this spark job definition is in. If not specified, it will appear at the root level. Eg: folder/subfolder1
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse spark-job-definition create", locals())


def wait(name, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a spark job definition is met.

    Required Parameters:
    - name -- The spark job definition name
    - workspace_name -- The workspace name.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse spark-job-definition wait", locals())


def update(file, name, workspace_name, folder_path=None, no_wait=None):
    '''
    Update a spark job definition.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The spark job definition name
    - workspace_name -- The workspace name.

    Optional Parameters:
    - folder_path -- The folder that this spark job definition is in. If not specified, it will appear at the root level. Eg: folder/subfolder1
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse spark-job-definition update", locals())




from ... pyaz_utils import _call_az

def show_execution_details(cluster_name, execution_id, resource_group):
    '''
    

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - execution_id -- The script execution id
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az hdinsight script-action show-execution-details", locals())


def list(cluster_name, resource_group):
    '''
    

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az hdinsight script-action list", locals())


def delete(cluster_name, name, resource_group):
    '''
    

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - name -- The name of the script.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az hdinsight script-action delete", locals())


def execute(cluster_name, name, resource_group, roles, script_uri, persist_on_success=None, script_parameters=None):
    '''
    Execute script actions on the specified HDInsight cluster.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - name -- The name of the script action.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - roles -- A space-delimited list of roles (nodes) where the script will be executed. Valid roles are headnode, workernode, zookeepernode, edgenode.
    - script_uri -- The URI to the script.

    Optional Parameters:
    - persist_on_success -- If the scripts needs to be persisted.
    - script_parameters -- The parameters for the script.
    '''
    return _call_az("az hdinsight script-action execute", locals())


def list_execution_history(cluster_name, resource_group):
    '''
    

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az hdinsight script-action list-execution-history", locals())


def promote(cluster_name, execution_id, resource_group):
    '''
    

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - execution_id -- The script execution id
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az hdinsight script-action promote", locals())




from ..... pyaz_utils import _call_az

def add(name, resource_group, scope, reset=None):
    '''
    Add scopes to this activity log alert.

    Required Parameters:
    - name -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scope -- None

    Optional Parameters:
    - reset -- None
    '''
    return _call_az("az monitor activity-log alert scope add", locals())


def remove(name, resource_group, scope):
    '''
    Removes scopes from this activity log alert.

    Required Parameters:
    - name -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scope -- None
    '''
    return _call_az("az monitor activity-log alert scope remove", locals())




from ....... pyaz_utils import _call_az

def add(match_variable, policy_name, resource_group, selector, selector_match_operator, type, version, group_name=None, rule_ids=None):
    '''
    Add a managed rule set to an exclusion.

    Required Parameters:
    - match_variable -- The variable to be excluded.
    - policy_name -- The name of the web application firewall policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - selector -- When matchVariable is a collection, operator used to specify which elements in the collection this exclusion applies to.
    - selector_match_operator -- When matchVariable is a collection, operate on the selector to specify which elements in the collection this exclusion applies to.
    - type -- The type of the web application firewall rule set.
    - version -- The version of the web application firewall rule set type. 0.1 is used for Microsoft_BotManagerRuleSet

    Optional Parameters:
    - group_name -- The managed rule group for exclusion.
    - rule_ids -- List of rules that will be disabled. If provided, --group-name must be provided too.
    '''
    return _call_az("az network application-gateway waf-policy managed-rule exclusion rule-set add", locals())


def remove(match_variable, policy_name, resource_group, selector, selector_match_operator, type, version, group_name=None):
    '''
    Remove managed rule set within an exclusion.

    Required Parameters:
    - match_variable -- The variable to be excluded.
    - policy_name -- The name of the web application firewall policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - selector -- When matchVariable is a collection, operator used to specify which elements in the collection this exclusion applies to.
    - selector_match_operator -- When matchVariable is a collection, operate on the selector to specify which elements in the collection this exclusion applies to.
    - type -- The type of the web application firewall rule set.
    - version -- The version of the web application firewall rule set type. 0.1 is used for Microsoft_BotManagerRuleSet

    Optional Parameters:
    - group_name -- The managed rule group for exclusion.
    '''
    return _call_az("az network application-gateway waf-policy managed-rule exclusion rule-set remove", locals())


def list(policy_name, resource_group):
    '''
    List all managed rule sets of an exclusion.

    Required Parameters:
    - policy_name -- The name of the web application firewall policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway waf-policy managed-rule exclusion rule-set list", locals())




'''
Manage Azure SignalR Service.
'''
from .. pyaz_utils import _call_az
from . import cors, identity, key, network_rule, upstream


def create(name, resource_group, sku, allowed_origins=None, default_action=None, enable_message_logs=None, location=None, service_mode=None, tags=None, unit_count=None):
    '''
    Creates a SignalR Service.

    Required Parameters:
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku -- The sku name of the signalr service. E.g. Standard_S1

    Optional Parameters:
    - allowed_origins -- space separated origins that should be allowed to make cross-origin calls (for example: http://example.com:12345). To allow all, use "*"
    - default_action -- Default action to apply when no rule matches.
    - enable_message_logs -- The switch for messaging logs which signalr service will generate or not
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - service_mode -- The service mode which signalr service will be working on
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - unit_count -- The number of signalr service unit count
    '''
    return _call_az("az signalr create", locals())


def delete(name, resource_group):
    '''
    Deletes a SignalR Service.

    Required Parameters:
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr delete", locals())


def list(resource_group=None):
    '''
    Lists all the SignalR Service under the current subscription.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr list", locals())


def show(name, resource_group):
    '''
    Get the details of a SignalR Service.

    Required Parameters:
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr show", locals())


def restart(name, resource_group):
    '''
    Restart an existing SignalR Service.

    Required Parameters:
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr restart", locals())


def update(name, resource_group, add=None, allowed_origins=None, default_action=None, enable_message_logs=None, force_string=None, remove=None, service_mode=None, set=None, sku=None, tags=None, unit_count=None):
    '''
    Update an existing SignalR Service.

    Required Parameters:
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - allowed_origins -- space separated origins that should be allowed to make cross-origin calls (for example: http://example.com:12345). To allow all, use "*"
    - default_action -- Default action to apply when no rule matches.
    - enable_message_logs -- The switch for messaging logs which signalr service will generate or not
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - service_mode -- The service mode which signalr service will be working on
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku -- The sku name of the signalr service. E.g. Standard_S1
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - unit_count -- The number of signalr service unit count
    '''
    return _call_az("az signalr update", locals())




from ...... pyaz_utils import _call_az

def add(policy_name, resource_group, type, version, group_name=None, rules=None):
    '''
    Add managed rule set to the WAF policy managed rules. For rule set and rules, please visit: https://docs.microsoft.com/azure/web-application-firewall/ag/application-gateway-crs-rulegroups-rules


    Required Parameters:
    - policy_name -- The name of the web application firewall policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - type -- The type of the web application firewall rule set.
    - version -- The version of the web application firewall rule set type. 0.1 is used for Microsoft_BotManagerRuleSet

    Optional Parameters:
    - group_name -- The name of the web application firewall rule set group.
    - rules -- List of rules that will be disabled. If provided, --group-name must be provided too
    '''
    return _call_az("az network application-gateway waf-policy managed-rule rule-set add", locals())


def update(policy_name, resource_group, type, version, add=None, force_string=None, group_name=None, remove=None, rules=None, set=None):
    '''
    Manage rules of a WAF policy. If --group-name and --rules are provided, override existing rules. If --group-name is provided, clear all rules under a certain rule group. If neither of them are provided, update rule set and clear all rules under itself. For rule set and rules, please visit: https://docs.microsoft.com/azure/web-application-firewall/ag/application-gateway-crs-rulegroups-rules


    Required Parameters:
    - policy_name -- The name of the web application firewall policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - type -- The type of the web application firewall rule set.
    - version -- The version of the web application firewall rule set type. 0.1 is used for Microsoft_BotManagerRuleSet

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - group_name -- The name of the web application firewall rule set group.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - rules -- List of rules that will be disabled. If provided, --group-name must be provided too
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network application-gateway waf-policy managed-rule rule-set update", locals())


def remove(policy_name, resource_group, type, version, group_name=None):
    '''
    Remove a managed rule set by rule set group name if rule_group_name is specified. Otherwise, remove all rule set.


    Required Parameters:
    - policy_name -- The name of the web application firewall policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - type -- The type of the web application firewall rule set.
    - version -- The version of the web application firewall rule set type. 0.1 is used for Microsoft_BotManagerRuleSet

    Optional Parameters:
    - group_name -- The name of the web application firewall rule set group.
    '''
    return _call_az("az network application-gateway waf-policy managed-rule rule-set remove", locals())


def list(policy_name, resource_group):
    '''
    List all managed rule set.

    Required Parameters:
    - policy_name -- The name of the web application firewall policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway waf-policy managed-rule rule-set list", locals())




from ... pyaz_utils import _call_az

def show(instance_id=None, location=None):
    '''
    Show the details of a database account that can be restored.

    Optional Parameters:
    - instance_id -- InstanceId of the Account
    - location -- Location
    '''
    return _call_az("az cosmosdb restorable-database-account show", locals())


def list(account_name=None, location=None):
    '''
    List all the database accounts that can be restored.

    Optional Parameters:
    - account_name -- Name of the Account
    - location -- Location
    '''
    return _call_az("az cosmosdb restorable-database-account list", locals())




from .... pyaz_utils import _call_az

def list(profile_name, resource_group):
    '''
    

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd log-analytic location list", locals())




'''
Manage origins within the specified origin group.
'''
from ... pyaz_utils import _call_az

def show(origin_group_name, origin_name, profile_name, resource_group):
    '''
    

    Required Parameters:
    - origin_group_name -- Name of the origin group which is unique within the endpoint.
    - origin_name -- Name of the origin.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd origin show", locals())


def list(origin_group_name, profile_name, resource_group):
    '''
    

    Required Parameters:
    - origin_group_name -- Name of the origin group which is unique within the endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd origin list", locals())


def create(enabled_state, host_name, origin_group_name, origin_name, profile_name, resource_group, enable_private_link=None, http_port=None, https_port=None, origin_host_header=None, priority=None, private_link_location=None, private_link_request_message=None, private_link_resource=None, private_link_sub_resource_type=None, weight=None):
    '''
    Create an AFD origin.

    Required Parameters:
    - enabled_state -- Whether to enable this origin.
    - host_name -- The address of the origin. Domain names, IPv4 addresses, and IPv6 addresses are supported.This should be unique across all origins in a origin group.
    - origin_group_name -- Name of the origin group which is unique within the endpoint.
    - origin_name -- Name of the origin.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - enable_private_link -- Indicates whether private link is enanbled on that origin.
    - http_port -- The port used for http requests to the origin.
    - https_port -- The port used for https requests to the origin.
    - origin_host_header -- The Host header to send for requests to this origin. If you leave this blank, the request hostname determines this value. Azure CDN origins, such as Web Apps, Blob Storage, and Cloud Services require this host header value to match the origin hostname by default.
    - priority -- Priority of origin in given origin group for load balancing. Higher priorities will not be used for load balancing if any lower priority origin is healthy. Must be between 1 and 5.
    - private_link_location -- The location of origin that will be connected to using the private link.
    - private_link_request_message -- The message that is shown to the approver of the private link request.
    - private_link_resource -- The resource ID of the origin that will be connected to using the private link.
    - private_link_sub_resource_type -- The sub-resource type of the origin that will be connected to using the private link.You can use "az network private-link-resource list" to obtain the supported sub-resource types.
    - weight -- Weight of the origin in given origin group for load balancing. Must be between 1 and 1000.
    '''
    return _call_az("az afd origin create", locals())


def update(origin_group_name, origin_name, profile_name, resource_group, enable_private_link=None, enabled_state=None, host_name=None, http_port=None, https_port=None, origin_host_header=None, priority=None, private_link_location=None, private_link_request_message=None, private_link_resource=None, private_link_sub_resource_type=None, weight=None):
    '''
    Update the settings of the specified AFD origin.

    Required Parameters:
    - origin_group_name -- Name of the origin group which is unique within the endpoint.
    - origin_name -- Name of the origin.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - enable_private_link -- Indicates whether private link is enanbled on that origin.
    - enabled_state -- Whether to enable this origin.
    - host_name -- The address of the origin. Domain names, IPv4 addresses, and IPv6 addresses are supported.This should be unique across all origins in a origin group.
    - http_port -- The port used for http requests to the origin.
    - https_port -- The port used for https requests to the origin.
    - origin_host_header -- The Host header to send for requests to this origin. If you leave this blank, the request hostname determines this value. Azure CDN origins, such as Web Apps, Blob Storage, and Cloud Services require this host header value to match the origin hostname by default.
    - priority -- Priority of origin in given origin group for load balancing. Higher priorities will not be used for load balancing if any lower priority origin is healthy. Must be between 1 and 5.
    - private_link_location -- The location of origin that will be connected to using the private link.
    - private_link_request_message -- The message that is shown to the approver of the private link request.
    - private_link_resource -- The resource ID of the origin that will be connected to using the private link.
    - private_link_sub_resource_type -- The sub-resource type of the origin that will be connected to using the private link.You can use "az network private-link-resource list" to obtain the supported sub-resource types.
    - weight -- Weight of the origin in given origin group for load balancing. Must be between 1 and 1000.
    '''
    return _call_az("az afd origin update", locals())


def delete(origin_group_name, origin_name, profile_name, resource_group, yes=None):
    '''
    

    Required Parameters:
    - origin_group_name -- Name of the origin group which is unique within the endpoint.
    - origin_name -- Name of the origin.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az afd origin delete", locals())




'''
Manage VM secrets.
'''
from ... pyaz_utils import _call_az

def format(secrets, certificate_store=None, keyvault=None, resource_group=None):
    '''
    Transform secrets into a form that can be used by VMs and VMSSes.

    Required Parameters:
    - secrets -- Space-separated list of key vault secret URIs. Perhaps, produced by 'az keyvault secret list-versions --vault-name vaultname -n cert1 --query "[?attributes.enabled].id" -o tsv'

    Optional Parameters:
    - certificate_store -- Windows certificate store names. Default: My
    - keyvault -- Name or ID of the key vault.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm secret format", locals())


def add(certificate, keyvault, name, resource_group, certificate_store=None):
    '''
    Add a secret to a VM.

    Required Parameters:
    - certificate -- key vault certificate name or its full secret URL
    - keyvault -- Name or ID of the key vault.
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - certificate_store -- Windows certificate store names. Default: My
    '''
    return _call_az("az vm secret add", locals())


def list(name, resource_group):
    '''
    List secrets on a VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm secret list", locals())


def remove(keyvault, name, resource_group, certificate=None):
    '''
    Remove a secret from a VM.

    Required Parameters:
    - keyvault -- Name or ID of the key vault.
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - certificate -- key vault certificate name or its full secret URL
    '''
    return _call_az("az vm secret remove", locals())




'''
Manage Azure Container Registry Tasks that use Cloud Native Buildpacks.
'''
from ... pyaz_utils import _call_az

def build(builder, image, registry, agent_pool=None, auth_mode=None, no_format=None, no_logs=None, no_wait=None, pack_image_tag=None, platform=None, pull=None, resource_group=None, timeout=None):
    '''
    Queues a quick build task that builds an app and pushes it into an Azure Container Registry.

    Required Parameters:
    - builder -- The name and tag of a Buildpack builder image.
    - image -- The name and tag of the image using the format: '-t repo/image:tag'.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - agent_pool -- The name of the agent pool.
    - auth_mode -- Auth mode of the source registry.
    - no_format -- Indicates whether the logs should be displayed in raw format
    - no_logs -- Do not show logs after successfully queuing the build.
    - no_wait -- Do not wait for the run to complete and return immediately after queuing the run.
    - pack_image_tag -- The tag of the 'pack' runner image ('mcr.microsoft.com/oryx/pack').
    - platform -- The platform where build/task is run, Eg, 'windows' and 'linux'. When it's used in build commands, it also can be specified in 'os/arch/variant' format for the resulting image. Eg, linux/arm/v7. The 'arch' and 'variant' parts are optional.
    - pull -- Pull the latest builder and run images before use.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - timeout -- The timeout in seconds.
    '''
    return _call_az("az acr pack build", locals())




'''
Manage function app deployments.
'''
from ... pyaz_utils import _call_az
from . import container, slot, source, user


def list_publishing_profiles(name, resource_group, slot=None, xml=None):
    '''
    Get the details for available function app deployment profiles.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    - xml -- retrieves the publishing profile details in XML format
    '''
    return _call_az("az functionapp deployment list-publishing-profiles", locals())


def list_publishing_credentials(name, resource_group, slot=None):
    '''
    Get the details for available function app publishing credentials.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp deployment list-publishing-credentials", locals())




'''
Manage Batch AI resources.
'''
from .. pyaz_utils import _call_az
from . import cluster, experiment, file_server, job, workspace


def list_usages(location):
    '''
    Gets the current usage information as well as limits for Batch AI resources for given location.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az batchai list-usages", locals())




'''
Manage resource provider features.
'''
from .. pyaz_utils import _call_az
from . import registration


def list(namespace=None):
    '''
    List preview features.

    Optional Parameters:
    - namespace -- the resource namespace, aka 'provider'
    '''
    return _call_az("az feature list", locals())


def show(name, namespace):
    '''
    

    Required Parameters:
    - name -- the feature name
    - namespace -- the resource namespace, aka 'provider'
    '''
    return _call_az("az feature show", locals())


def register(name, namespace):
    '''
    register a preview feature.

    Required Parameters:
    - name -- the feature name
    - namespace -- the resource namespace, aka 'provider'
    '''
    return _call_az("az feature register", locals())


def unregister(name, namespace):
    '''
    unregister a preview feature.

    Required Parameters:
    - name -- the feature name
    - namespace -- the resource namespace, aka 'provider'
    '''
    return _call_az("az feature unregister", locals())




from . pyaz_utils import _call_az
from . import account, acr, acs, aks, apim, appconfig, aro, bicep, bot, cache, cdn, cloud, config, container, cosmosdb, demo, deployment, deployment_scripts, disk, disk_access, disk_encryption_set, dms, extension, feature, group, hdinsight, identity, image, keyvault, local_context, lock, logicapp, managedapp, network, openshift, ppg, provider, redis, resource, sig, signalr, snapshot, sql, sshkey, staticwebapp, storage, tag, term, ts, webapp


def configure(defaults=None, list_defaults=None, scope=None):
    '''
    Manage Azure CLI configuration. This command is interactive.

    Optional Parameters:
    - defaults -- None
    - list_defaults -- list all applicable defaults
    - scope -- scope of defaults. Using "local" for settings only effective under current folder
    '''
    return _call_az("az configure", locals())


def feedback():
    '''
    Send feedback to the Azure CLI Team.
    '''
    return _call_az("az feedback", locals())


def find():
    '''
    I'm an AI robot, my advice is based on our Azure documentation as well as the usage patterns of Azure CLI and Azure ARM users. Using me improves Azure products and documentation.
    '''
    return _call_az("az find", locals())


def interactive(style=None, update=None):
    '''
    Start interactive mode. Installs the Interactive extension if not installed already.

    Optional Parameters:
    - style -- The colors of the shell.
    - update -- Update the Interactive extension to the latest available.
    '''
    return _call_az("az interactive", locals())


def login(allow_no_subscriptions=None, federated_token=None, password=None, scope=None, service_principal=None, tenant=None, use_cert_sn_issuer=None, use_device_code=None, username=None):
    '''
    Log in to Azure.

    Optional Parameters:
    - allow_no_subscriptions -- Support access tenants without subscriptions. It's uncommon but useful to run tenant level commands, such as 'az ad'
    - federated_token -- Federated token that can be used for OIDC token exchange.
    - password -- Credentials like user password, or for a service principal, provide client secret or a pem file with key and public certificate. Will prompt if not given.
    - scope -- Used in the /authorize request. It can cover only one static resource.
    - service_principal -- The credential representing a service principal.
    - tenant -- The AAD tenant, must provide when using service principals.
    - use_cert_sn_issuer -- used with a service principal configured with Subject Name and Issuer Authentication in order to support automatic certificate rolls
    - use_device_code -- Use CLI's old authentication flow based on device code. CLI will also use this if it can't launch a browser in your behalf, e.g. in remote SSH or Cloud Shell
    - username -- user name, service principal, or managed service identity ID
    '''
    return _call_az("az login", locals())


def logout(username=None):
    '''
    

    Optional Parameters:
    - username -- account user, if missing, logout the current active account
    '''
    return _call_az("az logout", locals())


def self_test():
    '''
    Runs a self-test of the CLI.
    '''
    return _call_az("az self-test", locals())


def rest(url, body=None, headers=None, method=None, output_file=None, resource=None, skip_authorization_header=None, uri_parameters=None):
    '''
    Invoke a custom request.

    Required Parameters:
    - url -- Request URL. If it doesn't start with a host, CLI assumes it as an Azure resource ID and prefixes it with the ARM endpoint of the current cloud shown by `az cloud show --query endpoints.resourceManager`. Common token {subscriptionId} will be replaced with the current subscription ID specified by `az account set`

    Optional Parameters:
    - body -- Request body. Use @{file} to load from a file. For quoting issues in different terminals, see https://github.com/Azure/azure-cli/blob/dev/doc/use_cli_effectively.md#quoting-issues
    - headers -- Space-separated headers in KEY=VALUE format or JSON string. Use @{file} to load from a file
    - method -- HTTP request method
    - output_file -- save response payload to a file
    - resource -- Resource url for which CLI should acquire a token from AAD in order to access the service. The token will be placed in the Authorization header. By default, CLI can figure this out based on --url argument, unless you use ones not in the list of "az cloud show --query endpoints"
    - skip_authorization_header -- Do not auto-append Authorization header
    - uri_parameters -- Query parameters in the URL. Space-separated queries in KEY=VALUE format or JSON string. Use @{file} to load from a file
    '''
    return _call_az("az rest", locals())


def version():
    '''
    Show the versions of Azure CLI modules and extensions in JSON format by default or format configured by --output
    '''
    return _call_az("az version", locals())


def upgrade(all=None, yes=None):
    '''
    Upgrade Azure CLI and extensions

    Optional Parameters:
    - all -- Enable updating extensions as well.
    - yes -- Do not prompt for checking release notes.
    '''
    return _call_az("az upgrade", locals())

